@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Harness::TestBuilder;
-$Test::BDD::Cucumber::Harness::TestBuilder::VERSION = '0.51';
+$Test::BDD::Cucumber::Harness::TestBuilder::VERSION = '0.52';
 =head1 NAME
 
 Test::BDD::Cucumber::Harness::TestBuilder - Pipes step output via Test::Builder
 
 =head1 VERSION
 
-version 0.51
+version 0.52
 
 =head1 DESCRIPTION
 
@@ -85,7 +85,7 @@ sub step_done {
             }
             $self->_note_step_data($step);
         } else {
-        TODO: { todo_skip $step_name, 1 }
+        TODO: { $self->_tb->todo_skip( $step_name, 1 ) }
             $self->_note_step_data($step);
         }
     } elsif ( $status eq 'passing' ) {
