@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Parser;
-$Test::BDD::Cucumber::Parser::VERSION = '0.51';
+$Test::BDD::Cucumber::Parser::VERSION = '0.52';
 =head1 NAME
 
 Test::BDD::Cucumber::Parser - Parse Feature files
 
 =head1 VERSION
 
-version 0.51
+version 0.52
 
 =head1 DESCRIPTION
 
@@ -32,8 +32,6 @@ L<Test::BDD::Cucumber::Model::Feature> object on success.
 use strict;
 use warnings;
 
-use File::Slurp;
-
 use Test::BDD::Cucumber::Model::Document;
 use Test::BDD::Cucumber::Model::Feature;
 use Test::BDD::Cucumber::Model::Scenario;
@@ -59,15 +57,19 @@ sub parse_string {
 
 sub parse_file {
     my ( $class, $string ) = @_;
-    return $class->_construct(
-        Test::BDD::Cucumber::Model::Document->new(
-            {
-                content =>
-                  scalar( read_file( $string, { binmode => ':utf8' } ) ),
-                filename => '' . $string
-            }
-        )
-    );
+    {
+        local $/;
+        open(my $in, '<', $string) or die $?;
+        binmode $in, 'utf8';
+        return $class->_construct(
+            Test::BDD::Cucumber::Model::Document->new(
+                {
+                    content => <$in>,
+                    filename => '' . $string
+                }
+            )
+        );
+    }
 }
 
 sub _construct {
